---

slug: /data-type-overview
---

# Data types

This chapter describes the data types supported by the current version of seekdb, including their properties and storage requirements.

The current version of seekdb supports the following data types:

* [Numeric types](200.numeric/100.numeric-type.md)

* [Date and time types](300.date-and-time-types/100.date-and-time-types.md)

* [String types](400.string/100.string-type-overview.md)

* [Large object types](500.large-object/100.large-object-and-text-type-overview.md)

* [Text types](500.large-object/100.large-object-and-text-type-overview.md)

* [Enumeration types](../100.data-type/600.enum-type.md)

* [Set types](../100.data-type/700.set-type.md)

* [JSON data types](800.json-formatted-data-type/100.json-formatted-data-types-of-syntax.md)

* [Spatial data types](900.spatial-data-type/100.spatial-data-type-overview-of-syntax.md)

* [Efficiently compressed bitmap data types](1000.roaring-bitmap-data-type/100.roaring-bitmap-data-type-overview.md)

* [Array data types](1200.array-data-type/100.array-data-type-overview.md)

* [Map data types](1300.map-data-type/100.map-data-type-overview.md)

seekdb allows you to compare two or more data values of any type. The result of the comparison can be:

* Nonzero / `TRUE`

* Zero / `FALSE`

* `NULL`

If the data types of the values being compared are different, seekdb determines a common data type for comparison based on the rules. Logically, all data values involved in the comparison must be converted to this data type before the comparison operation. If the comparison type is a text type, you must also determine a collation for the comparison.

For more information about the type conversion rules for comparison operations, see [Type conversion during expression evaluation](../200.expression/300.type-conversion-of-expression-evaluation.md).